@@ -1,7 +1,13 @@
 package HTTP::Proxy::Engine::Threaded;
+$HTTP::Proxy::Engine::Threaded::VERSION = '0.304';
 use strict;
 use HTTP::Proxy;
-use threads;
+
+my $can_use_threads;
+
+BEGIN {
+    $can_use_threads = eval 'use threads; 1';
+}
 
 # A massive hack of Engine::Fork to use the threads stuff
 # Basically created to work under win32 so that the filters
@@ -13,9 +19,14 @@ our %defaults = (
     max_clients => 60,
 );
 
-
 __PACKAGE__->make_accessors( qw( kids select ), keys %defaults );
 
+sub new {
+    die "This Perl not built to support threads"
+        if !$can_use_threads;
+    shift->SUPER::new(@_);
+}
+
 sub start {
     my $self = shift;
     $self->kids( [] );
@@ -102,7 +113,7 @@ Reap remaining child processes.
 
 L<HTTP::Proxy>, L<HTTP::Proxy::Engine>.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Angelos Karageorgiou C<< <angelos@unix.gr> >>. (Actual code)
 
@@ -110,7 +121,7 @@ Philippe "BooK" Bruhat, C<< <book@cpan.org> >>. (Documentation)
 
 =head1 COPYRIGHT
 
-Copyright 2010-2013, Philippe Bruhat.
+Copyright 2010-2015, Philippe Bruhat.
 
 =head1 LICENSE
 
